---
name: 'Issue: Question / Advice needed'
about: Ask a question about this project
title: ''
labels: question
assignees: ''

---

**What are you trying to achieve?**
Provide a brief background description of the problem you're trying to solve. Include information about the semantic engine you're working on (Power BI Desktop, Azure Analysis Services, etc.), as not everything is possible across engines.

**What have you tried so far?**
If applicable, describe the steps you have tried so far. For scripting-related questions, show the code that you have written.
